import { render, remove } from 'mcf-components'
import { DefinedObject } from 'mcf-objects/src'

import form from './components/form'



const uiDefinition = {
  htmlReference: { TYPE: 'string', required: true },
  errorList:     { TYPE: 'array' },
  message:       { TYPE: 'array'},

  name:        { TYPE: 'string' },
  adCall:      { TYPE: 'string' },
  libraryList: { TYPE: 'array' },
}
const uiInitialValues = {
  errorList: [],
  message: [],

  name: '',
  adCall: '',
  libraryList: [],
}

export default class UI extends DefinedObject {
  constructor(params, onSubmit) {
    super({
      fields: uiDefinition,
      values: params,
    })

    this.onSubmit = onSubmit
    this.setValue(uiInitialValues)
  }

  showMessage(messageTitle, message) {
    this.setValue({message: [messageTitle, message]})
    this.renderPage()
    this.setValue({message: []})
  }

  checkParams() {
    if (!this.getValue().name) this.updateArrayField('errorList', 'Name', true)
    if (!this.getValue().adCall) this.updateArrayField('errorList', 'Ad-call', true)
    if (this.getValue().libraryList.length === 0) this.updateArrayField('errorList', 'Libraries', true)
  }

  createErrorMessage() {
    let errorMessage = 'Please, review these inputs:'
    for (const error of this.getValue().errorList){
      errorMessage += '  · ' + error
    }
    return errorMessage
  }

  renderPage() {
    remove(this.getValue().htmlReference)
    render(form(this), this.getValue().htmlReference)
  }
}
